package com.omalleyland.mysimplebudget;

import android.app.*;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.*;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;

public class MainActivity extends Activity
{
	//Constants for managing LogCat and Selected Site
	private final static String	MYSIMPLEBUDGET_TAG	= "MySimpleBudget";				//For LogCat Messages to ensure same Tag across the Application
	private final static Integer 	CREATE_DEBIT		= 0;							//For easily tracking the Debit Posting Site
	private final static Integer 	SPENDING_INFO		= 1;							//For easily tracking the Spending Site
	private final static Integer SPENDING_GRAPH		= 2;							//For displaying spending graphs 
	private final static Integer BUDGET_INFO			= 3;							//For displaying budget info 

	//default web page to load until user defines them
	private final static String		DEFAULT_WEB_SITE	= "http://www.omalleyland.com";

	//Preference Management
	private final static String	SELECTED_VIEW_PREFERENCE	= "selected_view";
	private final static String 	SPENDING_SITE_PREFERENCE 	= "spending_info_site";
	private final static String 	DEBIT_SITE_PREFERENCE 		= "post_debit_site";
	private final static String 	SPENDING_GRAPH_PREFERENCE 	= "spending_graph_site";
	private final static String 	BUDGET_PREFERENCE 					= "budget_site";
	
	//Global Class Variables
	WebView webView; 			//webView object for holding budget web pages
	Integer	selectedView; 		//Integer for identifying which page is currently loaded
	String 	postDebitSite;		//Website for entering debits
	String 	spendingInfoSite;	//Website for viewing spending info
	String 	spendingGraphSite;	//Website for viewing spending graph info
	String  budgetSite;	//Website for viewing budget info

    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState)
	{
    	//restore layout properties and assign to XML layout main
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);

        //Assign webView object to variable, Set JavaScript as enabled and load the URL
		webView = (WebView) findViewById(R.id.webView1); 
		webView.getSettings().setJavaScriptEnabled(true); 		//this allows the spending info graphs to load		
		webView.setWebViewClient(new BudgetWebViewClient());	//keep links loading page in own webview		
    }
		
	@Override
	public void onStart() {
		super.onStart();
		
		//Use Default Preference Values if nothing has been saved yet.
		SharedPreferences sharedPrefs = PreferenceManager.getDefaultSharedPreferences(this);
		selectedView = sharedPrefs.getInt(SELECTED_VIEW_PREFERENCE, CREATE_DEBIT);
    postDebitSite = sharedPrefs.getString(DEBIT_SITE_PREFERENCE, DEFAULT_WEB_SITE);
		spendingInfoSite = sharedPrefs.getString(SPENDING_SITE_PREFERENCE, DEFAULT_WEB_SITE);
		spendingGraphSite = sharedPrefs.getString(SPENDING_GRAPH_PREFERENCE, DEFAULT_WEB_SITE);
		budgetSite = sharedPrefs.getString(BUDGET_PREFERENCE, DEFAULT_WEB_SITE);
    	Log.i(MYSIMPLEBUDGET_TAG, "onStart :: " + Integer.toString(selectedView));
    }
    
    @Override
    public void onResume() {
    	super.onResume();
    	Log.i(MYSIMPLEBUDGET_TAG, "onResume :: " + Integer.toString(selectedView));
    	
		//Load the appropriate page on layout update
		if(selectedView == SPENDING_INFO) {
			webView.clearView();
			webView.loadUrl(spendingInfoSite);
		}
		else if(selectedView == SPENDING_GRAPH) {
			webView.clearView();
			webView.loadUrl(spendingGraphSite);
		}
		else if(selectedView == BUDGET_INFO) {
			webView.clearView();
			webView.loadUrl(budgetSite);
		}
		else {
			webView.clearView();
			webView.loadUrl(postDebitSite);
			selectedView = CREATE_DEBIT;
		}
    }
    
    @Override
    public void onPause() {
    	super.onPause();
    	Log.i(MYSIMPLEBUDGET_TAG, "onPause :: " + Integer.toString(selectedView));
    	
    	SharedPreferences sharedPrefs = PreferenceManager.getDefaultSharedPreferences(this);
    	sharedPrefs.edit().putInt(SELECTED_VIEW_PREFERENCE, selectedView).commit();
    	sharedPrefs.edit().putString(DEBIT_SITE_PREFERENCE,postDebitSite).commit();
    	sharedPrefs.edit().putString(SPENDING_SITE_PREFERENCE,spendingInfoSite).commit();
    	sharedPrefs.edit().putString(SPENDING_GRAPH_PREFERENCE,spendingGraphSite).commit();
    	sharedPrefs.edit().putString(BUDGET_PREFERENCE,budgetSite).commit();
    }
    
    private class BudgetWebViewClient extends WebViewClient {
        @Override
        public boolean shouldOverrideUrlLoading(WebView view, String url) {
            view.loadUrl(url);
            return true;
        }
    }
    
    //Inflate Menu
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
    	MenuInflater inflater = getMenuInflater();
    	inflater.inflate(R.menu.main, menu);
    	return true;
    }
    
    //Create Click Event for Menu and execute code based on which item has been selected
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
    	// Handle Item Selection
    	switch (item.getItemId()) {
    	case R.id.menu_settings:
    		startActivity(new Intent(this, MainPreferencesActivity.class));    		
					return true;
			case R.id.budgetMenu:
				if(selectedView != BUDGET_INFO) {
					webView.clearView();
					webView.loadUrl(budgetSite);
					selectedView = BUDGET_INFO;
				}
				return true;
			case R.id.spendingInfoMenu:
				if(selectedView != SPENDING_INFO) {
					webView.clearView();
					webView.loadUrl(spendingInfoSite);
					selectedView = SPENDING_INFO;
				}
				return true;
    	case R.id.postDebitMenu:
    		if(selectedView != CREATE_DEBIT) {
	    		webView.clearView();
	    		webView.loadUrl(postDebitSite);
	    		selectedView = CREATE_DEBIT;
    		}
    		return true;
    	case R.id.spendingGraphMenu:
        	Log.i(MYSIMPLEBUDGET_TAG, "Loading '" + spendingGraphSite + "'");
    		if(selectedView != SPENDING_GRAPH) {
	    		webView.clearView();
	    		webView.loadUrl(spendingGraphSite);
	    		selectedView = SPENDING_GRAPH;
    		}
    		return true;
    	default:
    		Toast.makeText(getBaseContext(), "Default Action - Shouldn't see this", Toast.LENGTH_LONG).show();
    		return true;
    	}
    }
}
